====
List
====

The following methods are available under the `Series.list` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Series.list.all
    Series.list.any
    Series.list.drop_nulls
    Series.list.arg_max
    Series.list.arg_min
    Series.list.concat
    Series.list.contains
    Series.list.count_matches
    Series.list.diff
    Series.list.eval
    Series.list.explode
    Series.list.first
    Series.list.gather
    Series.list.get
    Series.list.head
    Series.list.join
    Series.list.last
    Series.list.len
    Series.list.max
    Series.list.mean
    Series.list.median
    Series.list.min
    Series.list.reverse
    Series.list.sample
    Series.list.set_difference
    Series.list.set_intersection
    Series.list.set_symmetric_difference
    Series.list.set_union
    Series.list.shift
    Series.list.slice
    Series.list.sort
    Series.list.std
    Series.list.sum
    Series.list.tail
    Series.list.to_array
    Series.list.to_struct
    Series.list.unique
    Series.list.n_unique
    Series.list.var
    Series.list.gather_every
